summaryrefslogtreecommitdiff
path: root/lib/gnutls_anon_cred.c
diff options
context:
space:
mode:
authorNikos Mavrogiannopoulos <nmav@gnutls.org>2002-09-01 18:57:39 +0000
committerNikos Mavrogiannopoulos <nmav@gnutls.org>2002-09-01 18:57:39 +0000
commitb40727621db92f5a55643355c84854bd668ad3a1 (patch)
tree142f4093074271400323cb55d83313b0ba4fd25d /lib/gnutls_anon_cred.c
parent582be7652d2843b4709e145edb68a3bfd92feaf3 (diff)
downloadgnutls-b40727621db92f5a55643355c84854bd668ad3a1.tar.gz
more cleanups
Diffstat (limited to 'lib/gnutls_anon_cred.c')
-rw-r--r--lib/gnutls_anon_cred.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/lib/gnutls_anon_cred.c b/lib/gnutls_anon_cred.c
index a230b42a8f..39ce5dede1 100644
--- a/lib/gnutls_anon_cred.c
+++ b/lib/gnutls_anon_cred.c
@@ -33,27 +33,27 @@
static int anon_tmp;
/**
* gnutls_anon_free_server_cred - Used to free an allocated GNUTLS_ANON_SERVER_CREDENTIALS structure
* @sc: is an &GNUTLS_ANON_SERVER_CREDENTIALS structure.
*
* This structure is complex enough to manipulate directly thus
* this helper function is provided in order to free (deallocate)
* the structure.
**/
-void gnutls_anon_free_server_cred( GNUTLS_ANON_SERVER_CREDENTIALS sc) {
+void gnutls_anon_free_server_credentials( GNUTLS_ANON_SERVER_CREDENTIALS sc) {
gnutls_free( sc);
}
/**
* gnutls_anon_allocate_server_cred - Used to allocate an GNUTLS_ANON_SERVER CREDENTIALS structure
* @sc: is a pointer to an &GNUTLS_ANON_SERVER_CREDENTIALS structure.
*
* This structure is complex enough to manipulate directly thus
* this helper function is provided in order to allocate
* the structure.
**/
-int gnutls_anon_allocate_server_cred( GNUTLS_ANON_SERVER_CREDENTIALS *sc) {
+int gnutls_anon_allocate_server_credentials( GNUTLS_ANON_SERVER_CREDENTIALS *sc) {
*sc = gnutls_calloc( 1, sizeof(ANON_SERVER_CREDENTIALS_INT));
(*sc)->dh_params = &_gnutls_dh_default_params;
@@ -63,27 +63,27 @@ int gnutls_anon_allocate_server_cred( GNUTLS_ANON_SERVER_CREDENTIALS *sc) {
/**
* gnutls_anon_free_client_cred - Used to free an allocated GNUTLS_ANON_CLIENT_CREDENTIALS structure
* @sc: is an &GNUTLS_ANON_CLIENT_CREDENTIALS structure.
*
* This structure is complex enough to manipulate directly thus
* this helper function is provided in order to free (deallocate)
* the structure.
**/
-void gnutls_anon_free_client_cred( GNUTLS_ANON_CLIENT_CREDENTIALS sc) {
+void gnutls_anon_free_client_credentials( GNUTLS_ANON_CLIENT_CREDENTIALS sc) {
return;
}
-
/**
- * gnutls_allocate_anon_client_cred - Used to allocate an GNUTLS_ANON_CLIENT CREDENTIALS structure
+ * gnutls_allocate_anon_client_credentials - Used to allocate an GNUTLS_ANON_CLIENT CREDENTIALS structure
* @sc: is a pointer to an &GNUTLS_ANON_CLIENT_CREDENTIALS structure.
*
* This structure is complex enough to manipulate directly thus
* this helper function is provided in order to allocate
* the structure.
**/
-int gnutls_anon_allocate_client_cred( GNUTLS_ANON_CLIENT_CREDENTIALS *sc) {
+int gnutls_anon_allocate_client_credentials( GNUTLS_ANON_CLIENT_CREDENTIALS *sc)
+{
/* anon_tmp is only there for *sc not to be null.
* it is not used at all;
*/
@@ -33,27 +33,27 @@
static int anon_tmp;
/**
- * gnutls_anon_free_server_cred - Used to free an allocated GNUTLS_ANON_SERVER_CREDENTIALS structure
+ * gnutls_anon_free_server_credentials - Used to free an allocated GNUTLS_ANON_SERVER_CREDENTIALS structure
* @sc: is an &GNUTLS_ANON_SERVER_CREDENTIALS structure.
*
@@ -33,27 +33,27 @@
}
/**
- * gnutls_anon_allocate_server_cred - Used to allocate an GNUTLS_ANON_SERVER CREDENTIALS structure
+ * gnutls_anon_allocate_server_credentials - Used to allocate an GNUTLS_ANON_SERVER CREDENTIALS structure
* @sc: is a pointer to an &GNUTLS_ANON_SERVER_CREDENTIALS structure.
*
@@ -63,27 +63,27 @@ int gnutls_anon_allocate_server_cred( GNUTLS_ANON_SERVER_CREDENTIALS *sc) {
/**
- * gnutls_anon_free_client_cred - Used to free an allocated GNUTLS_ANON_CLIENT_CREDENTIALS structure
+ * gnutls_anon_free_client_credentials - Used to free an allocated GNUTLS_ANON_CLIENT_CREDENTIALS structure
* @sc: is an &GNUTLS_ANON_CLIENT_CREDENTIALS structure.
*